@@ -33,7 +33,22 @@ bool exists(std::string name);
 
 namespace env {
 
-std::string get(const char *name, std::string dval);
+std::string get(const char *name, std::string dval = "");
+bool set(const char *name, std::string val, bool overwrite = true);
+bool unset(const char *name);
+
+class SetUnsetAfter {
+public:
+    SetUnsetAfter(const char *name, std::string val, bool overwrite = true) : name_(name) {
+        set(name_, val, overwrite);
+    };
+
+    ~SetUnsetAfter() {
+        unset(name_);
+    };
+private:
+    const char *name_;
+};
 
 }; // env
 
@@ -42,6 +57,7 @@ namespace string {
 std::vector<std::string> split(std::string strToSplit, char delimeter);
 bool endsWith(const std::string& str, const std::string& suffix);
 bool startsWith(const std::string& str, const std::string& prefix);
+bool compareInsensitive(const std::string& str1, const std::string& str2);
 
 }; // string
 }; // utils
